==> golangci-lint-2.5.0-deps.tar.xz: go-mod/github.com/godoc-lint/godoc-lint@v0.10.0/testdata/rule/max_len/normal/good.go <==
// some header

// (SS: slash-star godoc comment block)

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
package max_len

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
const NotLongLineConst = 0

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
//
//	?????????????????????????????????????????????????????????????????????????????
//	?????????????????????????????????????????????????????????????????????????????
//
// [long-link-1]: https://domain.com/long/path/??????????????????????????????????
// [long-link-2]: https://domain.com/long/path/??????????????????????????????????
const NotLongLineWithCodeAndLinkConst = 0

/*
?????????????????????????????????????????????????????????????????????????????
?????????????????????????????????????????????????????????????????????????????
*/
const NotLongLineConstSS = 0

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
const (
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupConst = 0
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupConst2 = 0
)

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
var NotLongLineVar = 0

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
var (
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupVar = 0
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupVar2 = 0
)

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
func NotLongLineFunc() {}

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineStruct struct{}

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineInterface interface{}

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineType int

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineTypeAlias = int

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type (
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineTypeGroup int
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineTypeGroup2 int
)

==> golangci-lint-2.6.1-deps.tar.xz: go-mod/github.com/godoc-lint/godoc-lint@v0.10.1/testdata/rule/max_len/normal/good.go <==
// some header

// (SS: slash-star godoc comment block)

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
package max_len

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
const NotLongLineConst = 0

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
//
//	?????????????????????????????????????????????????????????????????????????????
//	?????????????????????????????????????????????????????????????????????????????
//
// [long-link-1]: https://domain.com/long/path/??????????????????????????????????
// [long-link-2]: https://domain.com/long/path/??????????????????????????????????
const NotLongLineWithCodeAndLinkConst = 0

/*
?????????????????????????????????????????????????????????????????????????????
?????????????????????????????????????????????????????????????????????????????
*/
const NotLongLineConstSS = 0

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
const (
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupConst = 0
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupConst2 = 0
)

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
var NotLongLineVar = 0

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
var (
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupVar = 0
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineGroupVar2 = 0
)

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
func NotLongLineFunc() {}

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineStruct struct{}

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineInterface interface{}

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineType int

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type NotLongLineTypeAlias = int

// ?????????????????????????????????????????????????????????????????????????????
// ?????????????????????????????????????????????????????????????????????????????
type (
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineTypeGroup int
	// ?????????????????????????????????????????????????????????????????????????????
	// ?????????????????????????????????????????????????????????????????????????????
	NotLongLineTypeGroup2 int
)

// קთჩგხЖЩЯФГψΩΔλβशकधटभञΠΣΘΞΛΕημνξцшюёдאברגד한글조선በሀእልጽტყჟჩხძჯკჰჭդզէթժլխցկճմյնշվտր
// 漢字東京山川日月火水木金土天地國學者愛夢花空海雲人心中小大東京かなカタカナアイウエオЖФЩЯДЦШΩΔλβπψμνξшюёдאברגד한글조선በሀእልጽ한
type NotLongUtf8Check struct{}
